==> maleo_security-0.0.1-py3-none-any.whl: maleo_security/clients/http/controllers/hash/hmac.py <==
from maleo_foundation.models.transfers.results.client.controllers.http import BaseClientHTTPControllerResults
from maleo_security.clients.http.manager import MaleoSecurityHTTPClientManager
from maleo_security.models.transfers.parameters.hash.hmac import MaleoSecurityHMACHashParametersTransfers

class MaleoSecurityHMACHashHTTPClientController:
    @staticmethod
    async def hash(parameters:MaleoSecurityHMACHashParametersTransfers.Hash) -> BaseClientHTTPControllerResults:
        """Generate a hmac hash for the given message."""
        async with MaleoSecurityHTTPClientManager.get() as client:
            #* Define URL
            url = f"{MaleoSecurityHTTPClientManager.base_url}/v1/hashes/hmac/hash"

            #* Define headers
            headers = {
                "Content-Type": "application/json"
            }

            #* Construct body
            json = parameters.model_dump()

            #* Get Response
            response = await client.post(url=url, json=json, headers=headers)
            return BaseClientHTTPControllerResults(response=response)

    @staticmethod
    async def verify(parameters:MaleoSecurityHMACHashParametersTransfers.Verify) -> BaseClientHTTPControllerResults:
        """Verify a message against the given message hash."""
        async with MaleoSecurityHTTPClientManager.get() as client:
            #* Define URL
            url = f"{MaleoSecurityHTTPClientManager.base_url}/v1/hashes/hmac/verify"

            #* Define headers
            headers = {
                "Content-Type": "application/json"
            }

            #* Construct body
            json = parameters.model_dump()

            #* Get Response
            response = await client.post(url=url, json=json, headers=headers)
            return BaseClientHTTPControllerResults(response=response)

==> maleo_security-0.0.2-py3-none-any.whl: maleo_security/clients/http/controllers/hash/hmac.py <==
from maleo_foundation.models.transfers.results.client.controllers.http import BaseClientHTTPControllerResults
from maleo_security.clients.http.manager import MaleoSecurityHTTPClientManager
from maleo_security.models.transfers.parameters.hash.hmac import MaleoSecurityHMACHashParametersTransfers

class MaleoSecurityHMACHashHTTPClientController:
    @staticmethod
    async def hash(parameters:MaleoSecurityHMACHashParametersTransfers.Hash) -> BaseClientHTTPControllerResults:
        """Generate a hmac hash for the given message."""
        async with MaleoSecurityHTTPClientManager.get_client() as client:
            #* Define URL
            url = f"{MaleoSecurityHTTPClientManager.get_url()}/v1/hashes/hmac/hash"

            #* Define headers
            headers = {
                "Content-Type": "application/json"
            }

            #* Construct body
            json = parameters.model_dump()

            #* Get Response
            response = await client.post(url=url, json=json, headers=headers)
            return BaseClientHTTPControllerResults(response=response)

    @staticmethod
    async def verify(parameters:MaleoSecurityHMACHashParametersTransfers.Verify) -> BaseClientHTTPControllerResults:
        """Verify a message against the given message hash."""
        async with MaleoSecurityHTTPClientManager.get_client() as client:
            #* Define URL
            url = f"{MaleoSecurityHTTPClientManager.get_url()}/v1/hashes/hmac/verify"

            #* Define headers
            headers = {
                "Content-Type": "application/json"
            }

            #* Construct body
            json = parameters.model_dump()

            #* Get Response
            response = await client.post(url=url, json=json, headers=headers)
            return BaseClientHTTPControllerResults(response=response)
